@@ -1,5 +1,5 @@
 /* Low level interface to ptrace, for GDB when running under Unix.
-   Copyright (C) 1986-2025 Free Software Foundation, Inc.
+   Copyright (C) 1986-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -49,6 +49,8 @@
 
 static void pass_signal (int);
 
+static int gdb_has_a_terminal (void);
+
 static void child_terminal_ours_1 (target_terminal_state);
 
 /* Record terminal status separately for debugger and inferior.  */
@@ -57,16 +59,18 @@ static struct serial *stdin_serial;
 
 /* See terminal.h.  */
 
-scoped_gdb_ttystate::scoped_gdb_ttystate ()
+scoped_restore_tty_state::scoped_restore_tty_state ()
 {
-  m_ttystate = serial_get_tty_state (stdin_serial);
+  if (gdb_has_a_terminal ())
+    m_ttystate = serial_get_tty_state (stdin_serial);
 }
 
 /* See terminal.h.  */
 
-scoped_gdb_ttystate::~scoped_gdb_ttystate ()
+scoped_restore_tty_state::~scoped_restore_tty_state ()
 {
-  serial_set_tty_state (stdin_serial, m_ttystate);
+  if (m_ttystate != nullptr)
+    serial_set_tty_state (stdin_serial, m_ttystate);
 }
 
 /* Terminal related info we need to keep track of.  Each inferior
@@ -546,15 +550,15 @@ child_interrupt (struct target_ops *self)
 {
   /* Interrupt the first inferior that has a resumed thread.  */
   thread_info *resumed = NULL;
-  for (thread_info *thr : all_non_exited_threads ())
+  for (thread_info &thr : all_non_exited_threads ())
     {
-      if (thr->executing ())
+      if (thr.executing ())
 	{
-	  resumed = thr;
+	  resumed = &thr;
 	  break;
 	}
-      if (thr->has_pending_waitstatus ())
-	resumed = thr;
+      if (thr.has_pending_waitstatus ())
+	resumed = &thr;
     }
 
   if (resumed != NULL)
@@ -635,13 +639,7 @@ terminal_info::~terminal_info ()
 static struct terminal_info *
 get_inflow_inferior_data (struct inferior *inf)
 {
-  struct terminal_info *info;
-
-  info = inflow_inferior_data.get (inf);
-  if (info == NULL)
-    info = inflow_inferior_data.emplace (inf);
-
-  return info;
+  return &inflow_inferior_data.try_emplace (inf);
 }
 
 /* This is a "inferior_exit" observer.  Releases the TERMINAL_INFO member
