@@ -214,7 +214,7 @@ dump_msymbols (struct objfile *objfile, struct ui_file *outfile)
 	 not try to respect copy relocations.  */
       CORE_ADDR addr = (CORE_ADDR (msymbol->unrelocated_address ())
 			+ objfile->section_offsets[msymbol->section_index ()]);
-      gdb_puts (paddress (gdbarch, addr), outfile);
+      fputs_styled (paddress (gdbarch, addr), address_style.style (), outfile);
       gdb_printf (outfile, " %s", msymbol->linkage_name ());
       if (section)
 	{
@@ -276,8 +276,11 @@ dump_symtab_1 (struct symtab *symtab, struct ui_file *outfile)
       int len = l->nitems;
       for (int i = 0; i < len; i++)
 	{
-	  gdb_printf (outfile, _(" line %d at "), l->item[i].line);
-	  gdb_puts (paddress (gdbarch, l->item[i].pc (objfile)), outfile);
+	  gdb_printf (outfile, _(" line %ps at "),
+		      styled_string (line_number_style.style (),
+				     pulongest (l->item[i].line)));
+	  fputs_styled (paddress (gdbarch, l->item[i].pc (objfile)),
+			address_style.style (), outfile);
 	  if (l->item[i].is_stmt)
 	    gdb_printf (outfile, _("\t(stmt)"));
 	  gdb_printf (outfile, "\n");
@@ -304,9 +307,11 @@ dump_symtab_1 (struct symtab *symtab, struct ui_file *outfile)
 	     wants it.  */
 	  gdb_printf (outfile, _(", %d symbols in "),
 		      mdict_size (b->multidict ()));
-	  gdb_puts (paddress (gdbarch, b->start ()), outfile);
+	  fputs_styled (paddress (gdbarch, b->start ()),
+			address_style.style (), outfile);
 	  gdb_printf (outfile, "..");
-	  gdb_puts (paddress (gdbarch, b->end ()), outfile);
+	  fputs_styled (paddress (gdbarch, b->end ()),
+			address_style.style (), outfile);
 	  if (b->function ())
 	    {
 	      gdb_printf (outfile, _(", function %ps"),
@@ -314,8 +319,9 @@ dump_symtab_1 (struct symtab *symtab, struct ui_file *outfile)
 					 b->function ()->linkage_name ()));
 	      if (b->function ()->demangled_name () != NULL)
 		{
-		  gdb_printf (outfile, ", %s",
-			      b->function ()->demangled_name ());
+		  gdb_printf (outfile, ", %ps",
+			      styled_string (function_name_style.style (),
+					     b->function ()->demangled_name ()));
 		}
 	    }
 	  gdb_printf (outfile, "\n");
@@ -356,21 +362,13 @@ dump_symtab_1 (struct symtab *symtab, struct ui_file *outfile)
       struct compunit_symtab *cust = symtab->compunit ();
 
       if (cust->user != nullptr)
-	{
-	  const char *addr
-	    = host_address_to_string (cust->user->primary_filetab ());
-	  gdb_printf (outfile, _("Compunit user: %s\n"), addr);
-	}
-      if (cust->includes != nullptr)
-	for (int i = 0; ; ++i)
-	  {
-	    struct compunit_symtab *include = cust->includes[i];
-	    if (include == nullptr)
-	      break;
-	    const char *addr
-	      = host_address_to_string (include->primary_filetab ());
-	    gdb_printf (outfile, _("Compunit include: %s\n"), addr);
-	  }
+	gdb_printf (outfile, _("Compunit user: %s\n"),
+		    host_address_to_string (cust->user->primary_filetab ()));
+
+
+      for (compunit_symtab *include : cust->includes)
+	gdb_printf (outfile, _("Compunit include: %s\n"),
+		    host_address_to_string (include->primary_filetab ()));
     }
 }
 
@@ -522,8 +520,8 @@ print_symbol (struct gdbarch *gdbarch, struct symbol *symbol,
   if (symbol->domain () == LABEL_DOMAIN)
     {
       gdb_printf (outfile, _("label %s at "), symbol->print_name ());
-      gdb_puts (paddress (gdbarch, symbol->value_address ()),
-		outfile);
+      fputs_styled (paddress (gdbarch, symbol->value_address ()),
+		    address_style.style (), outfile);
       if (section)
 	gdb_printf (outfile, _(" section %s\n"),
 		    bfd_section_name (section->the_bfd_section));
@@ -592,7 +590,8 @@ print_symbol (struct gdbarch *gdbarch, struct symbol *symbol,
 
 	case LOC_STATIC:
 	  gdb_printf (outfile, _("static at "));
-	  gdb_puts (paddress (gdbarch, symbol->value_address ()), outfile);
+	  fputs_styled (paddress (gdbarch, symbol->value_address ()),
+			address_style.style (), outfile);
 	  if (section)
 	    gdb_printf (outfile, _(" section %s"),
 			bfd_section_name (section->the_bfd_section));
@@ -632,7 +631,8 @@ print_symbol (struct gdbarch *gdbarch, struct symbol *symbol,
 
 	case LOC_LABEL:
 	  gdb_printf (outfile, _("label at "));
-	  gdb_puts (paddress (gdbarch, symbol->value_address ()), outfile);
+	  fputs_styled (paddress (gdbarch, symbol->value_address ()),
+			address_style.style (), outfile);
 	  if (section)
 	    gdb_printf (outfile, _(" section %s"),
 			bfd_section_name (section->the_bfd_section));
@@ -808,21 +808,15 @@ maintenance_info_symtabs (const char *regexp, int from_tty)
 				    cust.user != nullptr
 				    ? host_address_to_string (cust.user)
 				    : "(null)");
-			if (cust.includes != nullptr)
+			if (!cust.includes.empty ())
 			  {
 			    gdb_printf (_("    ( includes\n"));
-			    for (int i = 0; ; ++i)
-			      {
-				struct compunit_symtab *include
-				  = cust.includes[i];
-				if (include == nullptr)
-				  break;
-				const char *addr
-				  = host_address_to_string (include);
-				gdb_printf ("      (%s %s)\n",
-					    "(struct compunit_symtab *)",
-					    addr);
-			      }
+
+			    for (compunit_symtab *include : cust.includes)
+			      gdb_printf ("      (%s %s)\n",
+					  "(struct compunit_symtab *)",
+					  host_address_to_string (include));
+
 			    gdb_printf ("    )\n");
 			  }
 			printed_compunit_symtab_start = 1;
