@@ -1,5 +1,5 @@
 /* Common definitions for remote server for GDB.
-   Copyright (C) 1993-2025 Free Software Foundation, Inc.
+   Copyright (C) 1993-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -130,7 +130,7 @@ extern unsigned long signal_pid;
 struct client_state
 {
   client_state ():
-    own_buf ((char *) xmalloc (PBUFSIZ + 1)) 
+    own_buf ((char *) xmalloc (PBUFSIZ + 1))
   {}
 
   /* The thread set with an `Hc' packet.  `Hc' is deprecated in favor of
@@ -197,6 +197,16 @@ struct client_state
      are not supported with qRcmd and m packets, but are still supported
      everywhere else.  This is for backward compatibility reasons.  */
   bool error_message_supported = false;
+
+  /* If true then we've agreed that the debugger will send all inferior
+     arguments as a single string.  When false the debugger will attempt
+     to split the inferior arguments before sending them.  */
+  bool single_inferior_argument = false;
+
+  /* When true, GDB supports receiving multiple watchpoint addresses within
+     a 'T' stop reply packet.  When false, GDB only expects (at most) a
+     single watchpoint address, and gdbserver must select one.  */
+  bool multiple_wp_addr_feature = false;
 };
 
 client_state &get_client_state ();
